<?php

namespace common\models;

use Yii;
use yii\behaviors\AttributeBehavior;
use yii\behaviors\TimestampBehavior;
use yii\db\ActiveRecord;

/**
 * This is the model class for table "feedback".
 *
 * @property integer $id
 * @property string  $name
 * @property string  $title
 * @property string  $email
 * @property string  $phone
 * @property string  $message
 * @property integer $created_at
 * @property string  $ip
 * @property string  $url
 * @property bool    $status
 */
class Feedback extends ActiveRecord
{

    const SCENARIO_FEEDBACK = 'feedback';
    const SCENARIO_CALLBACK = 'callback';

    public $returnUrl;

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'feedback';
    }

    /**
     * @inheritdoc
     */
    public function scenarios()
    {
        $scenarios = parent::scenarios();
        $scenarios = array_merge(
            $scenarios,
            [
                self::SCENARIO_FEEDBACK => [
                    'title',
                    'name',
                    'email',
                    'message',
                ],
                self::SCENARIO_CALLBACK => [
                    'title',
                    'name',
                    'phone',
                    'message',
                ],
            ]
        );
        return $scenarios;
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            [
                'class'              => TimestampBehavior::className(),
                'updatedAtAttribute' => false,
            ],
            [
                'class'      => AttributeBehavior::className(),
                'attributes' => [
                    ActiveRecord::EVENT_BEFORE_INSERT => 'ip',
                ],
                'value'      => function ($event) {
                    return \Yii::$app->request->userIP;
                },
            ],
            [
                'class'      => AttributeBehavior::className(),
                'attributes' => [
                    ActiveRecord::EVENT_BEFORE_INSERT => 'url',
                ],
                'value'      => function ($event) {
                    return \Yii::$app->request->referrer;
                },
            ],
        ];
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [
                [
                    'title',
                    'phone',
                    'name',
                    'email',
                ],
                'required',
            ],
            [
                [ 'email' ],
                'email',
            ],
            //                [
            //                    [ 'phone' ],
            //                    'match',
            //                    'pattern' => '/^\+38\(\d{3}\)\d{3}-\d{2}-\d{2}$/',
            //                ],
            [
                [
                    'title',
                    'name',
                    'phone',
                    'email',
                ],
                'string',
                'max' => 255,
            ],
            [
                [
                    'message',
                ],
                'string',
            ],
            [
                [
                    'status',
                ],
                'boolean',
            ],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id'         => Yii::t('app', 'id'),
            'name'       => Yii::t('app', 'name'),
            'phone'      => Yii::t('app', 'phone'),
            'created_at' => Yii::t('app', 'created_at'),
            'ip'         => Yii::t('app', 'ip'),
            'url'        => Yii::t('app', 'url'),
            'status'     => Yii::t('app', 'status'),
            'message'    => Yii::t('app', 'message'),
            'email'      => Yii::t('app', 'email'),
            'title'      => Yii::t('app', 'title'),
        ];
    }
}
