<?php
    /**
     * @var View         $this
     * @var string       $content
     * @var SeoComponent $seo
     * @var User         $user
     */
    use artbox\core\components\SeoComponent;
    use artbox\core\helpers\ImageHelper;
    use common\models\Feedback;
    use artbox\core\models\Page;
    use artbox\core\models\User;
    use common\models\Settings;
    use frontend\assets\AppAsset;
    use noam148\imagemanager\models\ImageManager;
    use yii\bootstrap\ActiveForm;
    use yii\bootstrap\Nav;
    use yii\bootstrap\Html;
    use yii\helpers\Json;
    use yii\helpers\Url;
    use yii\web\View;
    use yii\widgets\Breadcrumbs;
    
    AppAsset::register($this);
    $user = \Yii::$app->user->identity;
    $seo = Yii::$app->get('seo');
    $feedback = new Feedback();
    $settings = Settings::getInstance();
    $controller = Yii::$app->controller;
    $default_controller = Yii::$app->defaultRoute;
    $isHome = ( ( $controller->id === $default_controller ) && ( $controller->action->id === $controller->defaultAction ) ) ? true : false;
    /**
     * @var Page[] $pages
     */
    $pages = Page::find()
                 ->where([ 'in_menu' => true ])
                 ->with('lang.alias')
                 ->all();
    $logo = null;
    if ($settings->logo) {
        $logo_img = ImageManager::findOne($settings->logo);
        if ($logo_img) {
            $logo = $logo_img->getImagePathPrivate() ?? $logo;
        }
    }
    
    $this->registerMetaTag(
        [
            'name'    => 'description',
            'content' => $seo->desc,
        ]
    )
?>

<?php $this->beginPage() ?>
  
  <!DOCTYPE html>
  <html lang="<?= \Yii::$app->language ?>">
    <head>
      <meta charset="<?= \Yii::$app->charset ?>">
      <meta name="viewport" content="width=device-width, initial-scale=1">
        <?= Html::csrfMetaTags() ?>
      <title><?= Html::encode($seo->title) ?></title>
        <?php $this->head() ?>
    </head>
    <body>
        <?php $this->beginBody() ?>
      <!-- Google Analytics -->
      <script>
          (function(i, s, o, g, r, a, m) {
              i[ 'GoogleAnalyticsObject' ] = r;
              i[ r ] = i[ r ] || function() {
                      (i[ r ].q = i[ r ].q || []).push(arguments)
                  }, i[ r ].l = 1 * new Date();
              a = s.createElement(o), m = s.getElementsByTagName(o)[ 0 ];
              a.async = 1;
              a.src = g;
              m.parentNode.insertBefore(a, m)
          })(window, document, 'script', 'https://www.google-analytics.com/analytics.js', 'ga');

          ga('create', <?=$settings->ga_code?>, 'auto');
          ga('send', 'pageview');
  
      </script>
      <div id="all">
        <header>
          <!-- *** TOP ***
_________________________________________________________ -->
          <div id="top">
            <div class="container">
              <div class="row">
                <div class="col-xs-6 contact">
                  <p class="hidden-sm hidden-xs">
                      <?php
                          if (!empty($settings->phone)) {
                              $phone  = str_replace(" ", "", $settings->phone);
                              echo \Yii::t('app', 'head1');
                              echo Html::a($settings->phone, "tel:{$phone}");
                              if (!empty($settings->email)) {
                                  echo \Yii::t('app', 'head2');
                                  echo Html::a($settings->email, "mailto:$settings->email");
                              }
                          }
                      ?>
                  </p>
                  <p class="hidden-md hidden-lg">
                    <a href="#" data-animate-hover="pulse"><i class="fa fa-phone"></i></a>
                    <a href="#" data-animate-hover="pulse"><i class="fa fa-envelope"></i></a>
                  </p>
                </div>
                <div class="col-xs-6">
                  <div class="social">
                      <?php
                          if (!empty($settings->facebook)) {
                              echo Html::a(
                                  Html::icon(
                                      'facebook',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->facebook,
                                  [
                                      'class' => 'external facebook',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->vk)) {
                              echo Html::a(
                                  Html::icon(
                                      'vk',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->vk,
                                  [
                                      'class' => 'external vk',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->google)) {
                              echo Html::a(
                                  Html::icon(
                                      'google-plus',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->google,
                                  [
                                      'class' => 'external gplus',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->twitter)) {
                              echo Html::a(
                                  Html::icon(
                                      'twitter',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->twitter,
                                  [
                                      'class' => 'external twitter',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->ok)) {
                              echo Html::a(
                                  Html::icon(
                                      'odnoklassniki',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->ok,
                                  [
                                      'class' => 'external odnoklassniki',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->email)) {
                              echo Html::a(
                                  Html::icon(
                                      'envelope',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  "mailto:$settings->email",
                                  [
                                      'class' => 'email',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php $lang = explode("-",\Yii::$app->language);?>
                      <div class="langs">
                          <a<?php if($lang['0'] == 'ru') echo ' class="active"'; else echo ' href="/ru"';?>>ru</a>
                          <a<?php if($lang['0'] == 'ua') echo ' class="active"'; else echo ' href="/ua"';?>>ua</a>
                      </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
          <!-- *** TOP END *** -->
          
          <!-- *** NAVBAR ***
  _________________________________________________________ -->
          <div class="navbar-affixed-top" data-spy="affix" data-offset-top="200">
            
            <div class="navbar navbar-default yamm" role="navigation" id="navbar">
              
              <div class="container">
                <div class="navbar-header">
                  
                  <a class="navbar-brand home" href="<?php echo Url::home(); ?>">
                      <?php
                          echo ImageHelper::set($logo)
                                          ->setHeight(42)
                                          ->renderImage(
                                              [
                                                  'alt' => $settings->name,
                                              ]
                                          )
                      ?>
                  </a>
                  <div class="navbar-buttons">
                    <button type="button" class="navbar-toggle btn-template-main" data-toggle="collapse" data-target="#navigation">
                      <span class="sr-only"><?= Yii::t('app', 'Toggle navigation') ?></span>
                      <i class="fa fa-align-justify"></i>
                    </button>
                  </div>
                </div>
                
                <div class="navbar-collapse collapse" id="navigation">
                    <?php
                        $pagesLinks = [];
                        foreach ($pages as $page) {
                            $route = [
                                'page/view',
                                'id' => $page->id,
                            ];
                            if (!empty($page->lang->alias) && !empty($page->lang->alias->route)) {
                                $route = Json::decode($page->lang->alias->route);
                            }
                            $pagesLinks[] = [
                                'label' => $page->lang->title,
                                'url'   => $route,
                            ];
                        }
//                        echo Nav::widget(
//                            [
//                                'items'   => [
//                                    [
//                                        'label' => \Yii::t('app', 'Home'),
//                                        'url'   => [ 'site/index' ],
//                                    ],
//                                    [
//                                        'label'   => \Yii::t('app', 'Pages'),
//                                        'items'   => $pagesLinks,
//                                        'visible' => count($pagesLinks),
//                                    ],
//                                    [
//                                        'label' => \Yii::t('app', 'Contatcs'),
//                                        'url'   => [ 'site/contact' ],
//                                    ],
//                                    [
//                                        'label' => \Yii::t('app', 'About'),
//                                        'url'   => [ 'site/about' ],
//                                    ],
//                                ],
//                                'options' => [
//                                    'class' => 'nav navbar-nav navbar-right',
//                                ],
//                            ]
//                        );

                    echo Nav::widget(
                        [
                            'items'   => [
                                [
                                    'label' => \Yii::t('app', 'title10'),
                                    'url'   => [ '../#section1' ],
                                    'options' => ['class' => 'scroll-to',],
                                ],
                                [
                                    'label' => \Yii::t('app', 'title11'),
                                    'url'   => [ '../#section2' ],
                                    'options' => ['class' => 'scroll-to',],
                                ],
                                [
                                    'label' => \Yii::t('app', 'title12'),
                                    'url'   => [ '../#section3' ],
                                    'options' => ['class' => 'scroll-to',],
                                ],
                                [
                                    'label' => \Yii::t('app', 'title13'),
                                    'url'   => [ '../#section4' ],
                                    'options' => ['class' => 'scroll-to',],
                                ],
                            ],
                            'options' => [
                                'class' => 'nav navbar-nav navbar-right',
                            ],
                        ]
                    );
                    ?>
                </div>
                
                
                <div class="collapse clearfix" id="search">
                  
                  <form class="navbar-form" role="search">
                    <div class="input-group">
                      <input type="text" class="form-control" placeholder="<?= Yii::t('app', 'Search') ?>">
                      <span class="input-group-btn">

                    <button type="submit" class="btn btn-template-main"><i class="fa fa-search"></i></button>

                </span>
                    </div>
                  </form>
                
                </div>
                <!--/.nav-collapse -->
              
              </div>
            
            
            </div>
            <!-- /#navbar -->
          
          </div>
          
          <!-- *** NAVBAR END *** -->
        
        </header>
        
        <!-- *** FeedBack MODAL ***
_________________________________________________________ -->
        
        <div class="modal fade" id="feedback-modal" tabindex="-1" role="dialog" aria-labelledby="Login" aria-hidden="true">
          <div class="modal-dialog">
            
            <div class="modal-content">
              <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
                <h3 class="modal-title" id="Login"><?= Yii::t('app', 'back1') ?></h3>
              </div>
              <div class="modal-body">
                  
                  <?php $form = ActiveForm::begin(
                      [
                          'id'     => 'feedback-form',
                          'method' => 'POST',
                          'action' => '/site/feedback',
                      ]
                  ); ?>

                  <?= $form->field($feedback, 'title')
                            ->hiddenInput(); ?>

                  <?= $form->field($feedback, 'name')
                           ->textInput(); ?>
                  
                  <?= $form->field($feedback, 'email')
                           ->textInput(); ?>
                  
                  <?= $form->field($feedback, 'phone')
                           ->textInput(); ?>
                  
                  <?= $form->field($feedback, 'message')
                           ->textarea(
                               [
                                   'rows' => 4,
                               ]
                           ); ?>
                
                    <p class="text-center">
                        <?= Html::submitButton( \Yii::t('app', 'send1'),
                            [
                                'class'   => 'send-form btn btn-lg btn-template-primary button-consultation',
                                'onclick' => "ga('send', 'event', 'button-consultation.cec', 'send')",
                            ]
                        ) ?>
                    </p>
                    <p class="text-center">
                      <?= Html::submitButton( \Yii::t('app', 'send1'),
                          [
                              'class' => 'send-form btn btn-lg btn-template-primary button-сalculate',
                              'onclick' => "ga('send', 'event', 'button-сalculate the cost.cec', 'send')",
                          ]
                      ) ?>
                    </p>
                    <p class="text-center">
                      <?= Html::submitButton( \Yii::t('app', 'send1'),
                          [
                              'class' => 'send-form btn btn-lg btn-template-primary button-order',
                              'onclick' => "ga('send', 'event', 'button-order station.cec', 'send')",
                          ]
                      ) ?>
                    </p>
                  
                  <?php ActiveForm::end(); ?>
              
              </div>
            </div>
          </div>
        </div>
        
        <!-- *** FeedBack MODAL END *** -->
        
        <!-- *** FeedBack MODAL ***
_________________________________________________________ -->
        
        <div class="modal fade" id="success-modal" tabindex="-1" role="dialog" aria-labelledby="Success" aria-hidden="true">
          <div class="modal-dialog">
            
            <div class="modal-content">
              <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
                <h3 class="modal-title" id="Success"><?= Yii::t('app', 'success1') ?></h3>
              </div>
              <div class="modal-body">
                
                <p>Мы свяжемся с вами в ближайшее время</p>
                <p class="text-center">
                  <button type="button" class="btn btn-template-primary" data-dismiss="modal"><?= Yii::t('app', 'close') ?></button>
                </p>
              </div>
            </div>
          </div>
        </div>
        
        <!-- *** FeedBack MODAL END *** -->
        
        <!-- *** Breadcrumbs *** -->
          <?php
              if (!$isHome) {
                  ?>
                <div id="heading-breadcrumbs">
                  <div class="container">
                    <div class="row">
                      <div class="col-md-7">
                        <h1><?= $seo->h1 ?></h1>
                      </div>
                      <div class="col-md-5">
                          <?= Breadcrumbs::widget(
                              [
                                  'links' => isset($this->params[ 'breadcrumbs' ]) ? $this->params[ 'breadcrumbs' ] : [],
                              ]
                          ) ?>

                      </div>
                    </div>
                  </div>
                </div>
                  <?php
              }
          ?>
        <!-- *** Breadcrumbs END *** -->
          
          <?= $content ?>
        
        <!-- *** FOOTER ***
_________________________________________________________ -->
        
        <footer id="footer">
          <div class="container">
            <div class="col-md-6 col-sm-12">
                <?php
                    if (!empty($settings->about)) {
                        ?>
                      <h4><?php echo \Yii::t('app', 'about1'); ?></h4>
                      <p><?= Yii::t('app', $settings->about) ?></p>
                        <?php
                    }
                ?>
              <a href="#" class="btn btn-template-transparent-primary modaled" data-title="<?= Yii::t('app', 'back1') ?>" data-toggle="modal" data-target="#feedback-modal"><?= Yii::t('app', 'writeus') ?></a>
            </div>
            
            <div class="col-md-4 col-sm-12 col-md-offset-2">
              
              <h4><?php echo \Yii::t('app', 'title13'); ?></h4>
              
              <p>
                  <?php
                      if (!empty($settings->office)) {
                          echo \Yii::t(
                                  'app',
                                  'office {office}',
                                  [
                                      'office' => $settings->office,
                                  ]
                              ) . Html::tag('br');
                      }
                      if (!empty($settings->street)) {
                          echo $settings->street;
                          if (!empty($settings->house)) {
                              echo " " . $settings->house;
                          }
                          echo Html::tag('br');
                      }
                      if (!empty($settings->city)) {
                          echo \Yii::t('app', $settings->city);
                          echo Html::tag('br');
                      }
                      if (!empty($settings->country)) {
                          echo Html::tag('strong', \Yii::t('app', $settings->country));
                      }
                  ?>
              </p>
              
              <hr class="hidden-md hidden-lg hidden-sm">
            
            </div>
            
            <div class="col-md-12">
              <p class="pull-left">&copy; <?= date('Y') ?>. <?= $settings->name; ?></p>
            </div>
          </div>
          <!-- /.container -->
        </footer>
        <!-- /#footer -->
        
        <!-- *** FOOTER END *** -->
        
        <span id="back-to-top" title="<?= Yii::t('app', 'up') ?>"><i class="fa fa-arrow-up"></i></span>
      
      </div>
      <!-- /#all -->
        <?php $this->endBody() ?>
    <script>

        $('a.open_gal#gal01').on('click', function(){
            var openPhotoSwipeOne = function() {
                var titlelink = $("a.open_gal#gal01").data('title');
                var pswpElement1 = document.querySelectorAll('.pswp')[0];

                // build items array
                var items1 = [
                    {
                        src: '../img/galpics/01.jpg',
                        w: 960,
                        h: 720,
                        title: titlelink,
                    },
                    {
                        src: '../img/galpics/02.jpg',
                        w: 960,
                        h: 720,
                        title: titlelink,
                    },
                    {
                        src: '../img/galpics/03.jpg',
                        w: 960,
                        h: 720,
                        title: titlelink,
                    }
                ];

                // define options (if needed)
                var options1 = {
                    // history & focus options are disabled on CodePen
                    history: false,
                    focus: false,

                    showAnimationDuration: 0,
                    hideAnimationDuration: 0

                };

                var gallery1 = new PhotoSwipe( pswpElement1, PhotoSwipeUI_Default, items1, options1);
                gallery1.init();
            };

            openPhotoSwipeOne();
            return false;
        });

        $('a.open_gal#gal02').on('click', function(){
            var openPhotoSwipeTwo = function() {
                var pswpElement2 = document.querySelectorAll('.pswp')[0];
                var titlelink = $("a.open_gal#gal02").data('title');

                // build items array
                var items2 = [
                    {
                        src: '../img/galpics/11.jpg',
                        w: 960,
                        h: 510,
                        title: titlelink,
                    },
                    {
                        src: '../img/galpics/12.jpg',
                        w: 960,
                        h: 542,
                        title: titlelink,
                    },
                    {
                        src: '../img/galpics/13.jpg',
                        w: 960,
                        h: 542,
                        title: titlelink,
                    },
                    {
                        src: '../img/galpics/14.jpg',
                        w: 960,
                        h: 535,
                        title: titlelink,
                    },
                    {
                        src: '../img/galpics/15.jpg',
                        w: 1398,
                        h: 790,
                        title: titlelink,
                    },
                    {
                        src: '../img/galpics/16.jpg',
                        w: 1054,
                        h: 790,
                        title: titlelink,
                    },
                    {
                        src: '../img/galpics/17.jpg',
                        w: 1054,
                        h: 790,
                        title: titlelink,
                    }
                ];

                // define options (if needed)
                var options2 = {
                    // history & focus options are disabled on CodePen
                    history: false,
                    focus: false,

                    showAnimationDuration: 0,
                    hideAnimationDuration: 0

                };

                var gallery2 = new PhotoSwipe( pswpElement2, PhotoSwipeUI_Default, items2, options2);
                gallery2.init();
            };

            openPhotoSwipeTwo();
            return false;
        });

        $('a.open_gal#gal03').on('click', function(){
            var openPhotoSwipeThree = function() {
                var pswpElement3 = document.querySelectorAll('.pswp')[0];
                var titlelink = $("a.open_gal#gal03").data('title');

                // build items array
                var items3 = [
                    {
                        html: '<div class="video-wrapper"><iframe class="pswp__video" width="100%" height="100%" src="https://www.youtube-nocookie.com/embed/lpJ9sWE28N0?rel=0" frameborder="0" allowfullscreen></iframe></div>',
                        w: 960,
                        h: 640,
                        title: titlelink,
                    }
                ];

                // define options (if needed)
                var options3 = {
                    // history & focus options are disabled on CodePen
                    history: false,
                    focus: false,

                    showAnimationDuration: 0,
                    hideAnimationDuration: 0

                };

                var gallery3 = new PhotoSwipe( pswpElement3, PhotoSwipeUI_Default, items3, options3);
                gallery3.init();
            };

            openPhotoSwipeThree();
            return false;
        });
    </script>
    </body>
  </html>
<?php $this->endPage() ?>